import {
  useRadioGroupContext
} from "./chunk-NFAVX6Y6.mjs";

// src/use-radio.ts
import { useCallback, useId } from "react";
import { useMemo, useRef } from "react";
import { useFocusRing } from "@react-aria/focus";
import { useHover } from "@react-aria/interactions";
import { radio } from "@nextui-org/theme";
import { useRadio as useReactAriaRadio } from "@react-aria/radio";
import { __DEV__, warn, clsx, dataAttr } from "@nextui-org/shared-utils";
import { useDOMRef } from "@nextui-org/dom-utils";
import { chain, mergeProps } from "@react-aria/utils";
function useRadio(props) {
  var _a, _b, _c, _d, _e;
  const groupContext = useRadioGroupContext();
  const {
    as,
    ref,
    styles,
    id,
    value,
    children,
    description,
    size = (_a = groupContext == null ? void 0 : groupContext.size) != null ? _a : "md",
    color = (_b = groupContext == null ? void 0 : groupContext.color) != null ? _b : "primary",
    radius = (_c = groupContext == null ? void 0 : groupContext.radius) != null ? _c : "full",
    isDisabled: isDisabledProp = (_d = groupContext == null ? void 0 : groupContext.isDisabled) != null ? _d : false,
    disableAnimation = (_e = groupContext == null ? void 0 : groupContext.disableAnimation) != null ? _e : false,
    onChange = groupContext == null ? void 0 : groupContext.onChange,
    autoFocus = false,
    className,
    ...otherProps
  } = props;
  if (groupContext && __DEV__) {
    if ("checked" in otherProps) {
      warn('Remove props "checked" if in the Radio.Group.', "Radio");
    }
    if (value === void 0) {
      warn('Props "value" must be defined if in the Radio.Group.', "Radio");
    }
  }
  const Component = as || "label";
  const domRef = useDOMRef(ref);
  const inputRef = useRef(null);
  const labelId = useId();
  const isDisabled = useMemo(() => !!isDisabledProp, [isDisabledProp]);
  const isRequired = useMemo(() => {
    var _a2;
    return (_a2 = groupContext.isRequired) != null ? _a2 : false;
  }, [groupContext.isRequired]);
  const isInvalid = useMemo(() => groupContext.validationState === "invalid", [
    groupContext.validationState
  ]);
  const ariaRadioProps = useMemo(() => {
    const ariaLabel = otherProps["aria-label"] || typeof children === "string" ? children : void 0;
    const ariaDescribedBy = otherProps["aria-describedby"] || typeof description === "string" ? description : void 0;
    return {
      id,
      isDisabled,
      isRequired,
      "aria-label": ariaLabel,
      "aria-labelledby": otherProps["aria-labelledby"] || labelId,
      "aria-describedby": ariaDescribedBy
    };
  }, [labelId, id, isDisabled, isRequired]);
  const { inputProps } = useReactAriaRadio(
    {
      value,
      children,
      ...groupContext,
      ...ariaRadioProps
    },
    groupContext.groupState,
    inputRef
  );
  const isSelected = useMemo(() => inputProps.checked, [inputProps.checked]);
  const { hoverProps, isHovered } = useHover({ isDisabled });
  const { focusProps, isFocused, isFocusVisible } = useFocusRing({
    autoFocus
  });
  const slots = useMemo(
    () => radio({
      color,
      size,
      radius,
      isInvalid,
      isDisabled,
      isFocusVisible,
      disableAnimation
    }),
    [color, size, radius, isDisabled, isInvalid, isFocusVisible, disableAnimation]
  );
  const baseStyles = clsx(styles == null ? void 0 : styles.base, className);
  const getBaseProps = (props2 = {}) => {
    return {
      ...props2,
      ref: domRef,
      className: slots.base({ class: baseStyles }),
      "data-disabled": dataAttr(isDisabled),
      "data-checked": dataAttr(inputProps.checked),
      "data-invalid": dataAttr(isInvalid),
      ...mergeProps(hoverProps, otherProps)
    };
  };
  const getWrapperProps = (props2 = {}) => {
    return {
      ...props2,
      "data-active": dataAttr(isSelected),
      "data-hover": dataAttr(isHovered),
      "data-hover-unchecked": dataAttr(isHovered && !isSelected),
      "data-checked": dataAttr(isSelected),
      "data-focus": dataAttr(isFocused),
      "data-focus-visible": dataAttr(isFocused && isFocusVisible),
      "data-disabled": dataAttr(isDisabled),
      "data-invalid": dataAttr(isInvalid),
      "data-readonly": dataAttr(inputProps.readOnly),
      "aria-required": dataAttr(isRequired),
      "aria-hidden": true,
      className: clsx(slots.wrapper({ class: styles == null ? void 0 : styles.wrapper }))
    };
  };
  const getInputProps = (props2 = {}) => {
    return {
      ...props2,
      ref: inputRef,
      required: isRequired,
      "aria-required": dataAttr(isRequired),
      "data-invalid": dataAttr(isInvalid),
      "data-readonly": dataAttr(inputProps.readOnly),
      ...mergeProps(inputProps, focusProps),
      onChange: chain(inputProps.onChange, onChange)
    };
  };
  const getLabelProps = useCallback(
    (props2 = {}) => ({
      ...props2,
      id: labelId,
      "data-disabled": dataAttr(isDisabled),
      "data-checked": dataAttr(isSelected),
      "data-invalid": dataAttr(isInvalid),
      className: slots.label({ class: styles == null ? void 0 : styles.label })
    }),
    [slots, styles, isDisabled, isSelected, isInvalid]
  );
  const getLabelWrapperProps = useCallback(
    (props2 = {}) => ({
      ...props2,
      className: slots.labelWrapper({ class: styles == null ? void 0 : styles.labelWrapper })
    }),
    [slots, styles]
  );
  const getControlProps = useCallback(
    (props2 = {}) => ({
      ...props2,
      "data-disabled": dataAttr(isDisabled),
      "data-checked": dataAttr(isSelected),
      "data-invalid": dataAttr(isInvalid),
      className: slots.control({ class: styles == null ? void 0 : styles.control })
    }),
    [slots, isDisabled, isSelected, isInvalid]
  );
  return {
    Component,
    children,
    slots,
    styles,
    description,
    isSelected,
    isDisabled,
    isInvalid,
    isFocusVisible,
    getBaseProps,
    getWrapperProps,
    getInputProps,
    getLabelProps,
    getLabelWrapperProps,
    getControlProps
  };
}

export {
  useRadio
};
